@@ -1,7 +1,14 @@
 import click
 from sym.cli.decorators import setup_segment, setup_sentry
+from sym.cli.helpers.sym_group import SymGroup
 from sym.cli.helpers.updater import SymUpdater
 
+from sym.flow.cli.commands.debug import debug_commands
+from sym.flow.cli.commands.integrations import integration_commands
+from sym.flow.cli.commands.login import login
+from sym.flow.cli.commands.update import update
+from sym.flow.cli.commands.version import version
+
 from ..helpers.constants import (
     DEFAULT_API_URL,
     DEFAULT_AUTH_URL,
@@ -12,7 +19,9 @@ from ..helpers.global_options import GlobalOptions
 from ..version import __version__
 
 
-@click.group(name="symflow", context_settings={"help_option_names": ["-h", "--help"]})
+@click.group(
+    name="symflow", cls=SymGroup, context_settings={"help_option_names": ["-h", "--help"]}
+)
 @click.option(
     "--debug", is_flag=True, help="enable verbose debugging", envvar="SYM_DEBUG"
 )
@@ -38,9 +47,17 @@ def symflow(options: GlobalOptions, auth_url: str, api_url: str, debug: bool) ->
     Use this CLI to author Sym Flows.
     https://docs.symops.com/docs/support
     """
+
     options.debug = debug
     options.api_url = api_url
     options.auth_url = auth_url
     options.dprint(auth_url=auth_url, api_url=api_url)
 
-    SymUpdater().auto_update()
+    SymUpdater(debug=debug).auto_update()
+
+
+symflow.add_command(version)
+symflow.add_command(update)
+symflow.add_command(login)
+symflow.add_command(integration_commands)
+symflow.add_command(debug_commands)
