@@ -3,7 +3,6 @@ from pathlib import Path
 
 import immutables
 import pytest
-
 from sym.cli.helpers.contexts import push_env
 from sym.cli.tests.helpers.sandbox import Sandbox
 
@@ -11,11 +10,6 @@ from ...helpers.config import Config, store_login_config
 from ...models import AuthToken, Organization
 
 
-@pytest.fixture
-def sandbox(tmp_path: Path) -> Sandbox:
-    return Sandbox(tmp_path)
-
-
 @pytest.fixture
 def org() -> Organization:
     return Organization(slug="slug", client_id="client-id")
@@ -26,28 +20,16 @@ def email() -> str:
     return "ci@symops.io"
 
 
-@pytest.fixture
-def auth_token() -> AuthToken:
-    return AuthToken(
-        access_token="access-token",
-        refresh_token="refresh-token",
-        token_type="token-type",
-        expires_in=86400,
-        scope="scopes",
-    )
-
-
 __config_yaml = """
 auth_token:
-  access_token: access-token
+  access_token: access
   expires_in: 86400
-  refresh_token: refresh-token
+  refresh_token: refresh
   scope: scopes
-  token_type: token-type
+  token_type: type
+client_id: client-id
 email: ci@symops.io
-org:
-  client_id: client-id
-  slug: slug
+org: slug
 """
 
 
@@ -68,4 +50,4 @@ def test_read_login_config(sandbox, org, email, auth_token):
             fd.flush()
             assert Config.get_email() == email
             assert Config.get_org() == immutables.Map(org)
-            assert Config.get_auth_token() == immutables.Map(auth_token)
+            assert Config.get_access_token() == "access"
